==> haskell-feed-0.3.11.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-feed/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 0.3.11.1
id: feed-0.3.11.1-0044b3d36350d242264fbc09aa1daee4
key: feed_Bx5SR4O8Rb3DZHunpzkbxZ
license: BSD3
maintainer: Adam Bergmark <adam@bergmark.nl>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
author: Sigbjorn Finne <sof@forkIO.com>
exposed: True
exposed-modules:
    Paths_feed Text.Atom.Feed Text.Atom.Feed.Export
    Text.Atom.Feed.Import Text.Atom.Feed.Link Text.Atom.Feed.Validate
    Text.Atom.Pub Text.Atom.Pub.Export Text.DublinCore.Types
    Text.Feed.Constructor Text.Feed.Export Text.Feed.Import
    Text.Feed.Query Text.Feed.Translate Text.Feed.Types Text.Feed.Util
    Text.RSS.Export Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export
    Text.RSS1.Import Text.RSS1.Syntax Text.RSS1.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/feed-0.3.11.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/feed-0.3.11.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/feed-0.3.11.1
hs-libraries: HSfeed-0.3.11.1-Bx5SR4O8Rb3DZHunpzkbxZ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
    xml-1.3.14-47d6d03c8a900e03cf8951206101564b
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-feed-0.3.11.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-feed/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: feed
version: 0.3.11.1
id: feed-0.3.11.1-fbfd2a1da70f53d5f084de44df23dcef
key: feed_E78P3naxH5b8F7dAuME8gd
license: BSD3
maintainer: Adam Bergmark <adam@bergmark.nl>
homepage: https://github.com/bergmark/feed
synopsis: Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
    .
    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.
    .
    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.
category: Text
author: Sigbjorn Finne <sof@forkIO.com>
exposed: True
exposed-modules:
    Paths_feed Text.Atom.Feed Text.Atom.Feed.Export
    Text.Atom.Feed.Import Text.Atom.Feed.Link Text.Atom.Feed.Validate
    Text.Atom.Pub Text.Atom.Pub.Export Text.DublinCore.Types
    Text.Feed.Constructor Text.Feed.Export Text.Feed.Import
    Text.Feed.Query Text.Feed.Translate Text.Feed.Types Text.Feed.Util
    Text.RSS.Export Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export
    Text.RSS1.Import Text.RSS1.Syntax Text.RSS1.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/feed-0.3.11.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/feed-0.3.11.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/feed-0.3.11.1
hs-libraries: HSfeed-0.3.11.1-E78P3naxH5b8F7dAuME8gd
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
    xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
haddock-interfaces: /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html: /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
